diff --git a/src/python/grpcio/support.py b/src/python/grpcio/support.py
index 7730374df08204c923660ed44c604f5feb507d4b..f363f5fdc5033400d213afc01c90f1f17f8d9586 100644
--- a/src/python/grpcio/support.py
+++ b/src/python/grpcio/support.py
@@ -45,7 +45,10 @@ int main(int argc, char **argv) { return 0; }
 """
 C_PYTHON_DEV_ERROR_MESSAGE = """
 Could not find <Python.h>. This could mean the following:
-  * You're on Ubuntu and haven't `apt-get install`ed `python-dev`.
+  * You're on Ubuntu and haven't run `apt-get install python-dev`.
+  * You're on RHEL/Fedora and haven't run `yum install python-devel` or
+    `dnf install python-devel` (make sure you also have redhat-rpm-config
+    installed)
   * You're on Mac OS X and the usual Python framework was somehow corrupted
     (check your environment variables or try re-installing?)
   * You're on Windows and your Python installation was somehow corrupted